<?php
$lang['error_insufficientparams'] = 'Nedostatečn&eacute; (nebo pr&aacute;zdn&eacute;) parametry';
$lang['error_duplicatename'] = 'Položka s t&iacute;mto n&aacute;zvem již existuje';
$lang['detail_page'] = 'Str&aacute;nka detailu';
$lang['detail_template'] = '&Scaron;ablona detailu';
$lang['warning_preview'] = 'Varov&aacute;n&iacute;: Tento n&aacute;hledov&yacute; panel se chov&aacute; v&iacute;ce jako okno prohl&iacute;žeče a umožňuje navigaci z původně prohl&iacute;žen&eacute; str&aacute;nky. Pokud tak uděl&aacute;te, může nastat nepředv&iacute;dan&eacute; chov&aacute;n&iacute;. 
<br/><strong>Pozn&aacute;mka:</strong> Tento n&aacute;hled nenahraje vybran&eacute; soubory.';
$lang['article'] = 'Čl&aacute;nek';
$lang['preview'] = 'N&aacute;hled';
$lang['info_detail_returnid'] = 'T&iacute;mto nastaven&iacute;m zbol&iacute;te, jakou str&aacute;nku (a tedy i &scaron;ablonu) použ&iacute;t pro zobrazov&aacute;n&iacute; detailu. Pokud nebude tento parametr nastaven na platnou str&aacute;nku, nebude fungovat vlastn&iacute; URL adresa zadan&aacute; ve vlastnostech čl&aacute;nku. D&aacute;le tak&eacute; určuje v&yacute;choz&iacute; hodnotu parametru detailpage, pokud nebude v tagu {news} definov&aacute;n.';
$lang['title_detail_returnid'] = 'V&yacute;choz&iacute; str&aacute;nka pro zobrazen&iacute; detailu';
$lang['title_submission_settings'] = 'Vkl&aacute;d&aacute;n&iacute; novinek';
$lang['title_fesubmit_settings'] = 'Novinky od koncov&yacute;ch uživatelů (FEU)';
$lang['title_notification_settings'] = 'Upozorněn&iacute;';
$lang['title_detail_settings'] = 'Zobrazen&iacute; detailu';
$lang['error_invalidurl'] = 'Neplatn&eacute; URL <em>(možn&aacute; je již použito, nebo obsahuje nepovolen&eacute; znaky)</em>';
$lang['url'] = 'URL';
$lang['expired_searchable'] = 'Expirovan&eacute; čl&aacute;nky se mohou zobrazovat ve v&yacute;sledc&iacute;ch vyhled&aacute;v&aacute;n&iacute;';
$lang['helpshowall'] = 'Zobrazit v&scaron;echny čl&aacute;nky nehledě na jejich konečn&eacute; datum';
$lang['error_invaliddates'] = 'Jeden nebo v&iacute;ce zadan&yacute;ch datumů je neplatn&yacute;ch';
$lang['notify_n_draft_items_sub'] = '%d čl&aacute;nků';
$lang['notify_n_draft_items'] = 'M&aacute;te %s čl&aacute;nků, kter&eacute; nejsou publikov&aacute;ny.';
$lang['unlimited'] = 'Neomezeně';
$lang['none'] = 'Ž&aacute;dn&yacute;';
$lang['anonymous'] = 'Anonymn&iacute;';
$lang['unknown'] = 'Nezn&aacute;m&yacute;';
$lang['fesubmit_redirect'] = 'PageID nebo alias pro přesměrov&aacute;n&iacute; po odesl&aacute;n&iacute; čl&aacute;nku přes akcifesubmit';
$lang['allow_summary_wysiwyg'] = 'Povolit použit&iacute; WYSIWYG editoru v poli shrnut&iacute;.';
$lang['title_browsecat_template'] = 'Editor proch&aacute;zen&iacute; &scaron;ablon kategori&iacute;';
$lang['title_browsecat_sysdefault'] = 'V&yacute;choz&iacute; &scaron;ablona proch&aacute;zen&iacute; kategori&iacute;';
$lang['browsecattemplate'] = 'Proch&aacute;zen&iacute; &scaron;ablon kategori&iacute;';
$lang['error_filesize'] = 'Nahr&aacute;van&yacute; soubor překročil maxim&aacute;ln&iacute; povolenou velikost';
$lang['post_date_desc'] = 'Podle data publikace (nejnověj&scaron;&iacute; prvn&iacute;)';
$lang['post_date_asc'] = 'Podle data publikace (nejstar&scaron;&iacute; prvn&iacute;)';
$lang['expiry_date_desc'] = 'Podle data expirace sestupně';
$lang['expiry_date_asc'] = 'Podle data expirace vzestupně';
$lang['title_desc'] = 'Podle titulku sestupně (Z-A)';
$lang['title_asc'] = 'Podle titulku vzestupně (A-Z)';
$lang['status_desc'] = 'Podle stavu sestupně';
$lang['status_asc'] = 'Podle stavu vzestupně';
$lang['fesubmit_status'] = 'Stav novinek vložen&yacute;ch přes frontend (vlastn&iacute; str&aacute;nky)';
$lang['error_invalidfiletype'] = 'Tento typ souboru nen&iacute; možno nahr&aacute;t';
$lang['error_upload'] = 'Nastal probl&eacute;m při nahr&aacute;v&aacute;n&iacute; souboru';
$lang['error_movefile'] = 'Nelze vytvořit soubor: %s';
$lang['error_mkdir'] = 'Nelze vytvořit adres&aacute;ř: %s';
$lang['expiry_interval'] = 'Počet dn&iacute; (v&yacute;choz&iacute; hodnota) než čl&aacute;nek expiruje (pokud je zvolena expirace)';
$lang['removed'] = 'Odebr&aacute;no';
$lang['msg_contenttype_removed'] = 'Typ obsahu &quot;Novinky&quot; byl odebr&aacute;n. Pros&iacute;m um&iacute;stěte {news} tagy s př&iacute;slu&scaron;n&yacute;mi parametry do va&scaron;ich &scaron;ablon nebo str&aacute;nek pro obnoven&iacute; funkcionality.';
$lang['delete_selected'] = 'Smazat vybran&eacute; čl&aacute;nky';
$lang['areyousure_deletemultiple'] = 'Opravdu chcete smazat v&scaron;echny tyto čl&aacute;nky?\nTato akce je neodvolateln&aacute;.';
$lang['error_templatenamexists'] = '&Scaron;ablona tohoto jm&eacute;na již existuje.';
$lang['error_noarticlesselected'] = 'Nebyly vybr&aacute;ny ž&aacute;dn&eacute; čl&aacute;nky.';
$lang['reassign_category'] = 'Změnit kategorii na';
$lang['select'] = 'Zvolit';
$lang['approve'] = 'Nastavit stav na &quot;Publikov&aacute;no&quot;';
$lang['revert'] = 'Nastavit stav na &quot;Draft&quot;';
$lang['hide_summary_field'] = 'Skr&yacute;t pole shrnut&iacute; při přid&aacute;v&aacute;n&iacute; nebo &uacute;prav&aacute;ch čl&aacute;nků';
$lang['textbox'] = 'Textov&eacute; vstupn&iacute; pole';
$lang['checkbox'] = 'Za&scaron;krt&aacute;vac&iacute; pole';
$lang['textarea'] = 'Oblast textu';
$lang['file'] = 'Soubor';
$lang['auto_create_thumbnails'] = 'Automaticky vytvořit n&aacute;hledy pro soubory s těmito koncovkami';
$lang['allowed_upload_types'] = 'Pvolit nahr&aacute;v&aacute;n&iacute; pouze těchto typů souborů';
$lang['fielddefupdated'] = 'Popis pol&iacute;čka aktualizov&aacute;n';
$lang['editfielddef'] = 'Upravit popis pol&iacute;čka';
$lang['up'] = 'Nahoru';
$lang['down'] = 'Dolů';
$lang['fielddefdeleted'] = 'Popis pol&iacute;čka smaz&aacute;n';
$lang['nameexists'] = 'Pol&iacute;čko tohoto jm&eacute;na již existuje';
$lang['notanumber'] = 'Maxim&aacute;ln&iacute; d&eacute;lka nen&iacute; č&iacute;slo';
$lang['fielddef'] = 'Popis pol&iacute;čka';
$lang['fielddefadded'] = 'Popis pol&iacute;čka &uacute;spě&scaron;ně přid&aacute;n';
$lang['public'] = 'Veřejn&yacute;';
$lang['type'] = 'Typ';
$lang['info_maxlength'] = 'Maxim&aacute;ln&iacute; d&eacute;lka se vztahuje pouze na textov&aacute; pole';
$lang['maxlength'] = 'Maxim&aacute;ln&iacute; d&eacute;lka';
$lang['addfielddef'] = 'Přidat popis pole';
$lang['customfields'] = 'Popisy pole';
$lang['deprecated'] = 'nepodporov&aacute;no';
$lang['subject_newnews'] = 'Nov&yacute; čl&aacute;nek byl publikov&aacute;n';
$lang['email_subject'] = 'Předmět ochoz&iacute;ho e-mailu';
$lang['email_template'] = 'Form&aacute;t e-mailov&eacute; zpr&aacute;vy';
$lang['formsubmit_emailaddress'] = 'E-mailov&aacute; adresa, na kterou bude odesl&aacute;no upozorněn&iacute; na vložen&iacute; čl&aacute;nku';
$lang['extra'] = 'Extra';
$lang['uploadscategory'] = 'Kategorie uploadu';
$lang['title_available_templates'] = 'Dostupn&eacute; &scaron;ablony';
$lang['resettodefault'] = 'Reset do v&yacute;choz&iacute;ho nastaven&iacute;';
$lang['title_form_template'] = 'Editor &scaron;ablon formul&aacute;ře';
$lang['title_detail_template'] = 'Editor &scaron;ablony detailu';
$lang['title_summary_template'] = 'Editor &scaron;ablony souhrnu';
$lang['prompt_templatename'] = 'Jm&eacute;no &scaron;ablony';
$lang['prompt_template'] = 'Zdroj &scaron;ablony';
$lang['title_form_sysdefault'] = 'V&yacute;choz&iacute; &scaron;ablona formul&aacute;ře';
$lang['title_summary_sysdefault'] = 'V&yacute;choz&iacute; &scaron;ablona souhrnu';
$lang['title_detail_sysdefault'] = 'V&yacute;choz&iacute; &scaron;ablona detailu';
$lang['info_sysdefault2'] = '<strong>Pozn&aacute;mka:</strong> Tento panel obsahuje textov&aacute; pole, kter&eacute; v&aacute;m umožňuj&iacute; upravit sadu &scaron;ablon, jež jsou zobrazeny, když vytvoř&iacute;te &quot;novou&quot; &scaron;ablonu shrnut&iacute;, detailu nebo formul&aacute;ře. Změna obsahu na t&eacute;to str&aacute;nce a potvrzen&iacute; tlač&iacute;tkem &quot;Odeslat&quot; <strong>nezměn&iacute; ž&aacute;dn&eacute; současn&eacute; &scaron;ablony</strong>';
$lang['info_sysdefault'] = '(toto je v&yacute;choz&iacute; obsah nově vytořen&yacute;ch &scaron;ablon)';
$lang['template'] = '&Scaron;ablona';
$lang['prompt_name'] = 'Jm&eacute;no';
$lang['prompt_default'] = 'V&yacute;choz&iacute;';
$lang['prompt_newtemplate'] = 'Vytvořit novou &scaron;ablonu';
$lang['help_pagelimit'] = 'Maxim&aacute;ln&iacute; počet položek k zobrazen&iacute; (na str&aacute;nku).  Pokud tento parametr nen&iacute; zad&aacute;n, budou zobrazeny v&scaron;echy vyhovuj&iacute;c&iacute; položky.  Pokud je zad&aacute;n a položek je v&iacute;ce než uvedeno v tomto parametru, bude vložen text a odkazy pro proch&aacute;zen&iacute; v&yacute;sledků';
$lang['prompt_page'] = 'Str&aacute;nka';
$lang['firstpage'] = '<<';
$lang['prevpage'] = '<';
$lang['nextpage'] = '>';
$lang['lastpage'] = '>>';
$lang['prompt_of'] = 'z';
$lang['prompt_pagelimit'] = 'Limit str&aacute;nky';
$lang['prompt_sorting'] = 'Tř&iacute;dit podle';
$lang['title_filter'] = 'Filtry';
$lang['published'] = 'Publikov&aacute;no';
$lang['draft'] = 'Koncept';
$lang['expired'] = 'Vypr&scaron;elo';
$lang['author'] = 'Autor';
$lang['sysdefaults'] = 'Vr&aacute;tit v&yacute;choz&iacute;';
$lang['restoretodefaultsmsg'] = 'Tato operace vr&aacute;t&iacute; v&yacute;choz&iacute; nastaven&iacute; obsahu &scaron;ablony.  Opravdu to chcete prov&eacute;st?';
$lang['addarticle'] = 'Vložit novinku';
$lang['articleadded'] = 'Z&aacute;znam &uacute;spě&scaron;ně vložen.';
$lang['articleupdated'] = 'Z&aacute;znam &uacute;spě&scaron;ně aktualizov&aacute;n.';
$lang['articledeleted'] = 'Z&aacute;znam &uacute;spě&scaron;ně smaz&aacute;n.';
$lang['addcategory'] = 'Vložit kategorii';
$lang['categoryadded'] = 'Kategorie &uacute;spě&scaron;ně vložena.';
$lang['categoryupdated'] = 'Kategorie &uacute;spě&scaron;ně aktualizov&aacute;na.';
$lang['categorydeleted'] = 'Kategorie &uacute;spě&scaron;ně smaz&aacute;na.';
$lang['addnewsitem'] = 'Vložit novinku';
$lang['allcategories'] = 'V&scaron;echny kategorie';
$lang['allentries'] = 'V&scaron;echny položky';
$lang['areyousure'] = 'Opravdu chcete smazat?';
$lang['articles'] = 'Novinky';
$lang['cancel'] = 'Storno';
$lang['category'] = 'Kategorie';
$lang['categories'] = 'Kategorie';
$lang['default_category'] = 'V&yacute;choz&iacute; kategorie';
$lang['content'] = 'Obsah';
$lang['dateformat'] = '%s nen&iacute; ve spr&aacute;vn&eacute;m form&aacute;tu yyyy-mm-dd hh:mm:ss ';
$lang['delete'] = 'Smazat';
$lang['description'] = 'Vložit, upravit nebo smazat novinky';
$lang['formtemplate'] = '&Scaron;ablony formul&aacute;ře';
$lang['detailtemplate'] = '&Scaron;ablona detailu';
$lang['default_templates'] = 'V&yacute;choz&iacute; &scaron;ablony';
$lang['detailtemplateupdated'] = 'Upraven&aacute; &scaron;ablona Detailu &uacute;spě&scaron;ně vložena do datab&aacute;ze.';
$lang['displaytemplate'] = 'Zobrazit &scaron;ablonu';
$lang['edit'] = 'Upravit';
$lang['enddate'] = 'Konč&iacute;';
$lang['endrequiresstart'] = 'Vložen&iacute; data konce potřebuje tak&eacute; datum poč&aacute;tku';
$lang['entries'] = '%s položek';
$lang['status'] = 'Stav';
$lang['expiry'] = 'Vypr&scaron;&iacute;';
$lang['filter'] = 'Filtr';
$lang['more'] = 'V&iacute;ce';
$lang['category_label'] = 'Kategorie:';
$lang['author_label'] = 'Zaslal:';
$lang['extra_label'] = 'Extra:';
$lang['moretext'] = 'V&iacute;ce textu';
$lang['name'] = 'Jm&eacute;no';
$lang['news'] = 'Novinky';
$lang['news_return'] = 'N&aacute;vrat';
$lang['newcategory'] = 'Nov&aacute; kategorie';
$lang['needpermission'] = 'pro proveden&iacute; t&eacute;to funkce potřebujete opr&aacute;vněn&iacute; &#039;%s&#039;.';
$lang['nocategorygiven'] = 'Kategorie nezad&aacute;na';
$lang['startdatetoolate'] = 'Datum poč&aacute;tku je př&iacute;li&scaron; pozdn&iacute; (po datu konce?)';
$lang['nocontentgiven'] = 'Obsah nezad&aacute;n';
$lang['noitemsfound'] = '<strong>Ž&aacute;dn&eacute;</strong> položky nenalezeny v kategorii: %s';
$lang['nopostdategiven'] = 'Datum vložen&iacute; nezad&aacute;no';
$lang['note'] = '<em>Pozn&aacute;mka:</em> Datum mus&iacute; b&yacute;t ve form&aacute;tu &#039;yyyy-mm-dd hh:mm:ss&#039;';
$lang['notitlegiven'] = 'Nadpis nezad&aacute;n';
$lang['nonamegiven'] = 'Nezad&aacute;no jm&eacute;no';
$lang['numbertodisplay'] = 'Počet k zobrazen&iacute; (pr&aacute;zdn&eacute; zobraz&iacute; v&scaron;echny z&aacute;znamy)';
$lang['print'] = 'Tisknout';
$lang['postdate'] = 'Datum vložen&iacute;';
$lang['postinstall'] = 'Nastavte opr&aacute;vněn&iacute; &quot;Modify News&quot; v&scaron;em uživatelům, kteř&iacute; budou spravovat novinky.';
$lang['selectcategory'] = 'Vybrat kategorii';
$lang['showchildcategories'] = 'Zobrazit podř&iacute;zen&eacute; kategorie';
$lang['sortascending'] = 'Tř&iacute;dit vzestupně';
$lang['startdate'] = 'Zač&iacute;n&aacute;';
$lang['startoffset'] = 'Zač&iacute;t zobrazen&iacute; na n-t&eacute; položce';
$lang['startrequiresend'] = 'Vložen&iacute; data zač&aacute;tku potřebuje tak&eacute; datum ukončen&iacute;';
$lang['submit'] = 'Odeslat';
$lang['summary'] = 'Souhrn';
$lang['summarytemplate'] = '&Scaron;ablona souhrnu';
$lang['summarytemplateupdated'] = '&Scaron;ablona souhrnu novinek &uacute;spě&scaron;ně aktualizov&aacute;na.';
$lang['title'] = 'Nadpis';
$lang['options'] = 'Volby';
$lang['optionsupdated'] = 'Volby &uacute;spě&scaron;ně aktualizov&aacute;ny.';
$lang['useexpiration'] = 'Použ&iacute;t datum konce';
$lang['eventdesc-NewsArticleAdded'] = 'Odesl&aacute;no po vložen&iacute; položky.';
$lang['eventhelp-NewsArticleAdded'] = '<p>Odesl&aacute;no po vložen&iacute; položky.</p>
<h4>Parametry</h4>
<ul>
<li>&quot;news_id&quot; - Id položky</li>
<li>&quot;category_id&quot; - Id kategorie t&eacute;to položky</li>
<li>&quot;title&quot; - N&aacute;zev položky</li>
<li>&quot;content&quot; - Obsah položky</li>
<li>&quot;summary&quot; - Souhrn položky</li>
<li>&quot;status&quot; - Stav položky (&quot;draft&quot; nebo &quot;publish&quot;)</li>
<li>&quot;start_time&quot; - Datum, od kdy ma b&yacute;t položka zobrazov&aacute;na</li>
<li>&quot;end_time&quot; - Datum, od kdy se m&aacute; položka přestat zobrazovat</li>
<li>&quot;useexp&quot; - Zda m&aacute; b&yacute;t datum vypr&scaron;en&iacute; platnosti ignorov&aacute;no nebo ne</li>
</ul>
';
$lang['eventdesc-NewsArticleEdited'] = 'Odesl&aacute;no po editaci položky.';
$lang['eventhelp-NewsArticleEdited'] = '<p>Odesl&aacute;no po editaci položky.</p>
<h4>Parametry</h4>
<ul>
<li>&quot;news_id&quot; - Id položky</li>
<li>&quot;category_id&quot; - Id kategorie t&eacute;to položky</li>
<li>&quot;title&quot; - N&aacute;zev položky</li>
<li>&quot;content\&quot; - Obsah položky</li>
<li>&quot;summary&quot; - Souhrn položky</li>
<li>&quot;status&quot; - Stav položky (&quot;draft&quot; nebo &quot;publish&quot;)</li>
<li>&quot;start_time&quot; - Datum, od kdy ma b&yacute;t položka zobrazov&aacute;na</li>
<li>&quot;end_time&quot; - Datum, od kdy se m&aacute; položka přestat zobrazovat</li>
<li>&quot;useexp&quot; - Zda m&aacute; b&yacute;t datum vypr&scaron;en&iacute; platnosti ignorov&aacute;no nebo ne</li>
</ul>';
$lang['eventdesc-NewsArticleDeleted'] = 'Odesl&aacute;no po smaz&aacute;n&iacute; položky.';
$lang['eventhelp-NewsArticleDeleted'] = '<p>Odesl&aacute;no po smaz&aacute;n&iacute; položky.</p>
<h4>Parametry</h4>
<ul>
<li>&quot;news_id&quot; - Id položky</li>
</ul>
';
$lang['eventdesc-NewsCategoryAdded'] = 'Odesl&aacute;no po vložen&iacute; kategorie.';
$lang['eventhelp-NewsCategoryAdded'] = '<p>Odesl&aacute;no po vložen&iacute; kategorie.</p>
<h4>Parametry</h4>
<ul>
<li>&quot;category_id&quot; - Id kategorie</li>
<li>&quot;name&quot; - Jm&eacute;no kategorie</li>
</ul>
';
$lang['eventdesc-NewsCategoryEdited'] = 'Odesl&aacute;no po &uacute;pravě kategorie.';
$lang['eventhelp-NewsCategoryEdited'] = '<p>Odesl&aacute;no po &uacute;pravě kategorie.</p>
<h4>Parametry</h4>
<ul>
<li>&quot;category_id&quot; - Id kategorie</li>
<li>&quot;name&quot; - Jm&eacute;no kategorie</li>
<li>&quot;origname&quot; - Původn&iacute; jm&eacute;no kategorie</li>
</ul>
';
$lang['eventdesc-NewsCategoryDeleted'] = 'Odesl&aacute;no po smaz&aacute;n&iacute; kategorie.';
$lang['eventhelp-NewsCategoryDeleted'] = '<p>Odesl&aacute;no po smaz&aacute;n&iacute; kategorie.</p>
<h4>Parametry</h4>
<ul>
<li>&quot;category_id&quot; - Id kategorie</li>
<li>&quot;name&quot; - Jm&eacute;no smazan&eacute; kategorie</li>
</ul>
';
$lang['help_articleid'] = 'Tento parametr je možn&eacute; použ&iacute;t pouze u detailn&iacute;ho pohledu. Povoluje zadat jak&eacute; novinky zobrazit v detailn&iacute;m m&oacute;du. Pokud je použita speci&aacute;ln&iacute; hodnota -1, syst&eacute;m zobraz&iacute; nejnověj&scaron;&iacute;, publikovan&eacute;, nevypr&scaron;el&eacute; čl&aacute;nky.';
$lang['helpnumber'] = 'Maxim&aacute;ln&iacute; počet položek k zobrazen&iacute; - ponech&aacute;no pr&aacute;zdn&eacute; zobraz&iacute; v&scaron;echny položky.';
$lang['helpstart'] = 'Zač&iacute;t na n-t&eacute; položce -- pr&aacute;zdn&eacute; začne na prvn&iacute; položce.';
$lang['helpcategory'] = 'Zobrazit pouze položky t&eacute;to kategorie. Pro zobrazen&iacute; podpoložek použijte * za jm&eacute;nem. V&iacute;ce kategori&iacute; může b&yacute;t odděleno č&aacute;rkou.Ponech&aacute;no pr&aacute;zdn&eacute; zobraz&iacute; v&scaron;echny kategorie.';
$lang['helpmoretext'] = 'Text pro zobrazen&iacute; na konci novinky pokud jde přes d&eacute;lku souhrnu. Z&aacute;kladn&iacute; je &quot;more...&quot;';
$lang['helpsummarytemplate'] = 'Použ&iacute;vat oddělenou &scaron;ablonu pro souhrn. Tato &scaron;ablona mus&iacute; existovat a b&yacute;t viditeln&aacute;  v z&aacute;ložce &scaron;ablon souhrnu v administraci Novinek i když nen&iacute; v&yacute;choz&iacute;. Pokud tento parametr nen&iacute; zad&aacute;n, je použita &scaron;ablona označena jako v&yacute;choz&iacute;.';
$lang['helpformtemplate'] = 'Použ&iacute;t datab&aacute;zovou &scaron;ablonu pro zobrazen&iacute; formul&aacute;ře, slouž&iacute;c&iacute;ho k vložen&iacute; čl&aacute;nku. Tato &scaron;ablona mus&iacute; existovat a b&yacute;t viditeln&aacute; v panelu formul&aacute;řov&yacute;ch &scaron;ablon (v administračn&iacute;m rozhran&iacute; modulu Novinky), ale nemus&iacute; b&yacute;t &scaron;ablonou v&yacute;choz&iacute;. Pokud tento parametr nen&iacute; použit, pak bude použita &scaron;ablona moment&aacute;lně označen&aacute; jako v&yacute;choz&iacute;.';
$lang['helpbrowsecattemplate'] = 'Použ&iacute;t datab&aacute;zavou &scaron;ablonu pro zobrazen&iacute; prohl&iacute;žeče kategori&iacute;. Tato &scaron;ablona mus&iacute; existovat a mus&iacute; b&yacute;t viditeln&aacute; v z&aacute;ložce Proch&aacute;zen&iacute; &scaron;ablon kategori&iacute; v administraci modulu Novinky, ale nemus&iacute; b&yacute;t &scaron;ablonou v&yacute;choz&iacute;.  Pokud tento parametr nen&iacute; použit, pak bude použita &scaron;ablona moment&aacute;lně označen&aacute; jako v&yacute;choz&iacute;.';
$lang['helpdetailtemplate'] = 'Použ&iacute;vat oddělenou &scaron;ablonu pro detail. Tato &scaron;ablona mus&iacute; existovat a b&yacute;t viditeln&aacute;  v z&aacute;ložce &scaron;ablon detailu v administraci Novinek i když nen&iacute; v&yacute;choz&iacute;. Pokud tento parametr nen&iacute; zad&aacute;n, je použita &scaron;ablona označena jako v&yacute;choz&iacute;.';
$lang['helpsortby'] = 'Pole pro tř&iacute;děn&iacute;. Možnosti jsou: &quot;news_date&quot;, &quot;summary&quot;, &quot;news_data&quot;, &quot;news_category&quot;, &quot;news_title&quot;, &quot;news_extra&quot;, &quot;end_time&quot;, &quot;start_time&quot;, &quot;random&quot;.  v&yacute;choz&iacute; je &quot;news_date&quot;. Při zadan&iacute;m &quot;random&quot; je ignorov&aacute;n parametr sortasc.';
$lang['helpsortasc'] = 'Tř&iacute;dit novinky vzestupně.';
$lang['helpdetailpage'] = 'Str&aacute;nka pro zobrazn&iacute; detailu novinky. Toto může b&yacute;t buď alias nebo id str&aacute;nky. Umožňuje zobrazit detaily v jin&eacute; &scaron;abloně než souhrn.';
$lang['helpshowarchive'] = 'Zobrazit pouze expirovan&eacute; novinky.';
$lang['helpbrowsecat'] = 'Zobrazit prohl&iacute;žiteln&yacute; seznam kategori&iacute;.';
$lang['helpaction'] = 'Přepsat v&yacute;choz&iacute; akci. Možn&eacute; hodnoty jsou:
<ul>
<li>&quot;detail&quot; - pro zobrazen&iacute; zadan&eacute;ho čl&aacute;nku v detailn&iacute;m m&oacute;du.</li>
<li>&quot;default&quot; - pro zobrazen&iacute; pohledu souhrnu</li>
<li>&quot;fesubmit&quot; - pro zobrazen&iacute; formul&aacute;ře na str&aacute;nk&aacute;ch povoluj&iacute;c&iacute; vkl&aacute;dat novinky koncov&yacute;m uživatelům. Pro zobrazen&iacute; vybran&eacute;ho WYSIWYG editoru (Administrace str&aacute;nek - Glob&aacute;ln&iacute; nastaven&iacute;) vložte do oblasti pro metadata <code>{cms_init_editor}</code>.</li>
<li>&quot;browsecat&quot; - pro zobrazen&iacute; prohled&aacute;vateln&eacute;ho seznamu kategori&iacute;.</li>
</ul>';
$lang['help'] = '<h3>Důležit&eacute; pozn&aacute;mky</h3>
<p>Verze Novinek 2.9 a vy&scaron;&scaron;&iacute; odstraňuje ze &scaron;ablony parametr formatpostdate a dateformat.  M&iacute;sto toho se pro form&aacute;tov&aacute;n&iacute; data použ&iacute;v&aacute; cms_date_format (jak je naznačeno ve v&yacute;choz&iacute;ch &scaron;ablon&aacute;ch) a v &scaron;ablon&aacute;ch se použ&iacute;v&aacute; entry->postdate m&iacute;sto entry->formatpostdate.</p>
<h3>Co to děl&aacute;?</h3>
<p>Novinky jsou modul pro zobrazov&aacute;n&iacute; novinek na str&aacute;nk&aacute;ch, podobn&eacute; stylu blogů, ale s v&iacute;ce vlastnostmi!.  Po instalaci modulu je do Administračn&iacute;ho panelu přid&aacute;no menu, kter&eacute; umožňuje vyb&iacute;rat nebo vkl&aacute;dat kategorie str&aacute;nek. Pot&eacute; co je kategorie vybr&aacute;na nebo vytvořena, je zobrazen seznam novinek t&eacute;to kategorie.  Zde můžete přid&aacute;vat, upravovat nebo mazat novinky zvolen&eacute; kategorie.</p>
<h4>Mnoho metod zobrazen&iacute;</h4>
<p>Podporovan&eacute; paraemtry modulu Novinky a podpora pro mnoho &scaron;ablon d&aacute;v&aacute; neomezen&eacute; možnosti zobrazen&iacute; novinek.</p>
<h4>Vlastn&iacute; pole</h4>
<p>Modul Novinky podporuje definov&aacute;n&iacute; mnoha vlastn&iacute;ch pol&iacute; (včetně souborů a obr&aacute;zků), což dovoluje připojit pdf soubory nebo obr&aacute;zky do Va&scaron;ich novinek.</p>
        <h4>Kategorie</h4>
	<p>Novinky nab&iacute;zej&iacute; hierarchick&eacute; tř&iacute;děn&iacute; kategori&iacute; pro organizaci Va&scaron;ich novinek. Novinka může b&yacute;t pouze v jedn&eacute; kategorii.</p>
        <h4>RSS Feedy</h4>
        <p>Novinky podporuj&iacute; generov&aacute;n&iacute; jednoduch&yacute;ch rss feedů z Va&scaron;ich novinek, takže uživatele&eacute; mohou b&yacute;t st&aacute;le informov&aacute;n&iacute; co se na Va&scaron;ich str&aacute;nk&aacute;ch děje.</p>
	<h4>Vypr&scaron;en&iacute; a status</h4>
	<p>Každ&aacute; položka může m&iacute;t voliteln&eacute; datum vypr&scaron;en&iacute;, po kter&eacute;m se již nebude zobrazovat na Va&scaron;ich str&aacute;nk&aacute;ch. Novinky mohou b&yacute;t tak&eacute; označeny jako <em>draft</em> pro jejich trval&eacute; odstraněn&iacute; ze str&aacute;nek.</p>
	<h3>Bezpečnost</h3>
	<p>uživatel mus&iacute; n&aacute;ležet do skupiny s opr&aacute;vněn&iacute;m &#039;Modify News&#039; pro vkl&aacute;d&aacute;n&iacute; nebo &uacute;pravu novinek.</p>
        <p>Rovněž pro smaz&aacute;n&iacute; novinek mus&iacute; uživatel n&aacute;ležet do skupiny s opr&aacute;vněn&iacute;m  &#039;Delete News Articles&#039;.</p>
	<p>Pro změnu &scaron;ablon, uživatel mus&iacute; n&aacute;ležet do skupiny s opr&aacute;vněn&iacute;m &#039;Modify Templates&#039; permission.</p>
	<p>Pro &uacute;pravu glob&aacute;ln&iacute;ch nastaven&iacute; novinek mus&iacute; uživatel n&aacute;ležet do skupiny s opr&aacute;vněn&iacute;m  &#039;Modify Site Preferences&#039; permission.</p>
	<p>A pro schv&aacute;len&iacute; zobrazov&aacute;n&iacute; novinek na str&aacute;nk&aacute;ch mus&iacute; uživatel n&aacute;ležet do skupiny s opr&aacute;vněn&iacute;m  &#039;Approve News&#039; permission.</p>
	<h3>Jak se použ&iacute;v&aacute;?</h3>
	<p>Nejjednodu&scaron;&scaron;&iacute; je to přes obalovac&iacute; tag {news} (obal&iacute; modul pro zjednodu&scaron;en&iacute; syntaxe). Toto vlož&iacute; modul Novinky do str&aacute;nek kdekoliv si přejete. K&oacute;d vypad&aacute; nějak n&aacute;sledovně: <code>{news number=&#039;5&#039;}</code></p>
<h3>&Scaron;ablony</h3>
<p>Od verze 2.3 modul Novinky obsahuje v&iacute;ce datab&aacute;zov&yacute;ch &scaron;ablon a nad&aacute;le nepodporuje dodatečn&eacute; soubory se &scaron;ablonami. Uživatel&eacute; použ&iacute;vaj&iacute;c&iacute; tento star&yacute; &scaron;ablonovac&iacute; syst&eacute;m by měli prov&eacute;st tyto kroky (pro každ&yacute; soubor &scaron;ablony):</p>
<ul>
<li>Zkop&iacute;rovat &scaron;ablonu do schr&aacute;nky</li>
<li>Vytvořit novou datab&aacute;zovou &scaron;ablonu <em>(buď pro souhrn nebo detail)</em>. Přiřadit &scaron;abloně stejn&eacute; jm&eacute;no (včetně koncovky .tpl) podle star&eacute; souborov&eacute; &scaron;ablony a vložit do n&iacute; obsah ze schr&aacute;nky.</li>
<li>Stisknout odeslat</li>
</ul>
<p>N&aacute;sledov&aacute;n&iacute; těchto kroků vyře&scaron;&iacute; probl&eacute;m s nenalezen&iacute;m &scaron;ablon novinek a jin&eacute; podobn&eacute; chyby smarty při aktualizaci CMS obsahuj&iacute;c&iacute; Novinky ve verzi 2.3 nebo vy&scaron;&scaron;&iacute;.</p>';
$lang['utma'] = '156861353.947599811.1321089285.1321089285.1321103008.2';
$lang['utmz'] = '156861353.1321089285.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['qca'] = 'P0-2065764558-1319293569112';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>